==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/password_policy/l10n/pt_BR.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "A senha expirou. Use \"esqueceu a senha\" para redefini-la",
    "Password must not have been used recently before." : "A senha não pode ter sido usada recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "A senha está entre as 1.000.000 mais comuns. Por favor, torne-a única.",
    "Password is present in compromised password list. Please choose a different password." : "A senha está presente na lista de senhas comprometidas. Escolha uma senha diferente.",
    "Password needs to be at least %s characters long." : "A senha precisa ter no mínimo %s caracteres.",
    "Password needs to contain at least one numeric character." : "A senha precisa conter pelo menos um caractere numérico.",
    "Password needs to contain at least one special character." : "A senha precisa conter pelo menos um caractere especial.",
    "Password needs to contain at least one lower and one upper case character." : "A senha precisa conter pelo menos um caractere minúsculo e um maiúsculo.",
    "Password policy" : "Política de senhas",
    "Allows admins to configure a password policy" : "Permite aos administradores configurarem uma política de senha",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permitir que o administrador defina determinadas pré-condições para a senha, por exemplo,  um tamanho mínimo",
    "General password policies" : "Políticas gerais de senhas",
    "Add policy set" : "Adicionar conjunto de políticas",
    "Login policies" : "Políticas de login",
    "Password history size" : "Tamanho do histórico de senhas",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Número de senhas a serem mantidas (com hash seguro) para evitar que os usuários reutilizem senhas usadas anteriormente.",
    "Maximum login attempts" : "Máximo de tentativas de login",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Número de tentativas de login antes que a conta do usuário seja desativada até que uma ação manual seja executada. (0 para sem limite)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observe que esta opção destina-se a proteger contas atacadas. As contas desativadas devem ser reativadas manualmente pela administração. Os invasores que tentarem adivinhar as senhas das contas terão seus endereços IP bloqueados pela proteção de força bruta independente desta configuração.",
    "Number of days until user password expires" : "Número de dias até a expiração da senha do usuário",
    "Password expiration" : "Expiração da senha",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Aviso: habilitar a expiração de senha é atualmente considerado um risco de segurança por diversas agências de segurança.",
    "Remove policy" : "Remover política",
    "Minimum password length" : "Tamanho mínimo para senhas",
    "Forbid common passwords" : "Proibir senhas comuns",
    "Enforce upper and lower case characters" : "Forçar caracteres maiúsculos e minúsculos",
    "Enforce numeric characters" : "Forçar aplicar caracteres numéricos",
    "Enforce special characters" : "Forçar aplicar caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verificar a senha com relação à lista de senhas violadas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Essa verificação cria um hash da senha e envia os primeiros 5 caracteres desse hash para a API haveibeenpwned.com para recuperar uma lista de todos os hashes que começam com eles. Em seguida, ele verifica com o servidor Nextcloud se o hash da senha está no conjunto de resultados.",
    "Account password policies" : "Políticas de senha da conta",
    "Share password policies" : "Compartilhar políticas de senha",
    "Unknown error" : "Erro desconhecido",
    "Minimal length has to be a non negative number" : "O tamanho mínimo não pode ser um número negativo",
    "History size has to be a non negative number" : "O tamanho do histórico não pode ser um número negativo",
    "Expiration days have to be a non negative number" : "Dias para expiração não pode ser um número negativo",
    "Maximum login attempts have to be a non negative number" : "O máximo de tentativas de login não pode ser um número negativo",
    "Settings saved" : "Configurações salvas",
    "Error while saving settings" : "Error while saving settings",
    "User password history" : "Histórico de senhas do usuário",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observe que esta opção se destina a proteger contas atacadas. As contas desativadas devem ser reativadas manualmente pela administração. Os invasores que tentarem adivinhar as senhas das contas terão seus endereços IP bloqueados pela proteção de força bruta independente desta configuração."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/password_policy/l10n/pt_BR.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "A senha expirou. Use \"esqueceu a senha\" para redefini-la",
    "Password must not have been used recently before." : "A senha não pode ter sido usada recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "A senha está entre as 1.000.000 mais comuns. Por favor, torne-a única.",
    "Password is present in compromised password list. Please choose a different password." : "A senha está presente na lista de senhas comprometidas. Escolha uma senha diferente.",
    "Password needs to be at least %s characters long." : "A senha precisa ter no mínimo %s caracteres.",
    "Password needs to contain at least one numeric character." : "A senha precisa conter pelo menos um caractere numérico.",
    "Password needs to contain at least one special character." : "A senha precisa conter pelo menos um caractere especial.",
    "Password needs to contain at least one lower and one upper case character." : "A senha precisa conter pelo menos um caractere minúsculo e um maiúsculo.",
    "Password policy" : "Política de senhas",
    "Allows admins to configure a password policy" : "Permite aos administradores configurarem uma política de senha",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permitir que o administrador defina determinadas pré-condições para a senha, por exemplo,  um tamanho mínimo",
    "General password policies" : "Políticas gerais de senhas",
    "Add policy set" : "Adicionar conjunto de políticas",
    "Login policies" : "Políticas de login",
    "Password history size" : "Tamanho do histórico de senhas",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Número de senhas a serem mantidas (com hash seguro) para evitar que os usuários reutilizem senhas usadas anteriormente.",
    "Maximum login attempts" : "Máximo de tentativas de login",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Número de tentativas de login antes que a conta do usuário seja desativada até que uma ação manual seja executada. (0 para sem limite)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observe que esta opção destina-se a proteger contas atacadas. As contas desativadas devem ser reativadas manualmente pela administração. Os invasores que tentarem adivinhar as senhas das contas terão seus endereços IP bloqueados pela proteção de força bruta independente desta configuração.",
    "Number of days until user password expires" : "Número de dias até a expiração da senha do usuário",
    "Password expiration" : "Expiração da senha",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Aviso: habilitar a expiração de senha é atualmente considerado um risco de segurança por diversas agências de segurança.",
    "Remove policy" : "Remover política",
    "Minimum password length" : "Tamanho mínimo para senhas",
    "Forbid common passwords" : "Proibir senhas comuns",
    "Enforce upper and lower case characters" : "Forçar caracteres maiúsculos e minúsculos",
    "Enforce numeric characters" : "Forçar aplicar caracteres numéricos",
    "Enforce special characters" : "Forçar aplicar caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verificar a senha com relação à lista de senhas violadas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Essa verificação cria um hash da senha e envia os primeiros 5 caracteres desse hash para a API haveibeenpwned.com para recuperar uma lista de todos os hashes que começam com eles. Em seguida, ele verifica com o servidor Nextcloud se o hash da senha está no conjunto de resultados.",
    "Account password policies" : "Políticas de senha da conta",
    "Share password policies" : "Compartilhar políticas de senha",
    "Unknown error" : "Erro desconhecido",
    "Minimal length has to be a non negative number" : "O tamanho mínimo não pode ser um número negativo",
    "History size has to be a non negative number" : "O tamanho do histórico não pode ser um número negativo",
    "Expiration days have to be a non negative number" : "Dias para expiração não pode ser um número negativo",
    "Maximum login attempts have to be a non negative number" : "O máximo de tentativas de login não pode ser um número negativo",
    "Settings saved" : "Configurações salvas",
    "Error while saving settings" : "Erro ao salvar as configurações",
    "User password history" : "Histórico de senhas do usuário",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observe que esta opção se destina a proteger contas atacadas. As contas desativadas devem ser reativadas manualmente pela administração. Os invasores que tentarem adivinhar as senhas das contas terão seus endereços IP bloqueados pela proteção de força bruta independente desta configuração."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
